SeikaBindings class

FFI bindings for seika C library

Constructors

SeikaBindings(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
SeikaBindings.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seika_analyze(Pointer<Uint8> rgba_image, Pointer<Uint8> mask, int width, int height, Pointer<SeikaComplexity> out) int
seika_config_balanced() SeikaConfig
seika_config_fast() SeikaConfig
seika_config_quality() SeikaConfig
seika_inpaint(Pointer<Uint8> rgba_image, Pointer<Uint8> mask, int width, int height, Pointer<SeikaConfig> config, Pointer<Uint8> out_rgba) int
seika_version() Pointer<Char>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited