SeikaConfig class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- iterations ↔ int
-
getter/setter pair
- patch_size ↔ int
-
getter/setter pair
- pyramid_levels ↔ int
-
getter/setter pair
- random_search_radius ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- texture_variance_threshold ↔ double
-
getter/setter pair
- use_affine_invariant ↔ int
-
getter/setter pair
- use_criminisi_order ↔ int
-
getter/setter pair
- use_fourier_constraint ↔ int
-
getter/setter pair
- use_image_melding ↔ int
-
getter/setter pair
- use_multi_scale ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited